@@ -141,6 +141,7 @@ typedef struct __options {
     int no_x_check;
     int no_nvidia_xconfig_question;
     int run_distro_scripts;
+    int no_nouveau_check;
 
     char *opengl_prefix;
     char *opengl_libdir;
@@ -317,7 +318,12 @@ typedef struct {
 #define FILE_TYPE_UTILITY_LIB_SYMLINK           0x0000000000020000ULL
 #define FILE_TYPE_XMODULE_SHARED_LIB            0x0000000000040000ULL
 #define FILE_TYPE_XMODULE_SYMLINK               0x0000000000080000ULL
-#define FILE_TYPE_MANPAGE                       0x0000000000100000ULL
+/* Create a symlink only if the file doesn't exist */
+#define FILE_TYPE_XMODULE_NEWSYM                0x0000000000100000ULL
+#define FILE_TYPE_MANPAGE                       0x0000000000200000ULL
+#define FILE_TYPE_CUDA_HEADER                   0x0000000000400000ULL
+#define FILE_TYPE_CUDA_LIB                      0x0000000000800000ULL
+#define FILE_TYPE_CUDA_SYMLINK                  0x0000000001000000ULL
 #define FILE_TYPE_UTILITY_BIN_SYMLINK           0x0000000010000000ULL
 
 /* file class: this is used to distinguish OpenGL libraries */
@@ -335,12 +341,14 @@ typedef struct {
 #define FILE_TYPE_XMODULE_LIB      (FILE_TYPE_XMODULE_SHARED_LIB)
 
 #define FILE_TYPE_INSTALLABLE_FILE (FILE_TYPE_OPENGL_LIB         | \
+                                    FILE_TYPE_CUDA_LIB           | \
                                     FILE_TYPE_XLIB_LIB           | \
                                     FILE_TYPE_TLS_LIB            | \
                                     FILE_TYPE_UTILITY_LIB        | \
                                     FILE_TYPE_DOCUMENTATION      | \
                                     FILE_TYPE_MANPAGE            | \
                                     FILE_TYPE_OPENGL_HEADER      | \
+                                    FILE_TYPE_CUDA_HEADER        | \
                                     FILE_TYPE_KERNEL_MODULE      | \
                                     FILE_TYPE_INSTALLER_BINARY   | \
                                     FILE_TYPE_UTILITY_BINARY     | \
@@ -350,15 +358,19 @@ typedef struct {
 
 #define FILE_TYPE_HAVE_PATH        (FILE_TYPE_XMODULE_LIB        | \
                                     FILE_TYPE_XMODULE_SYMLINK    | \
+                                    FILE_TYPE_XMODULE_NEWSYM     | \
                                     FILE_TYPE_MANPAGE            | \
                                     FILE_TYPE_OPENGL_HEADER      | \
+                                    FILE_TYPE_CUDA_HEADER        | \
                                     FILE_TYPE_TLS_LIB            | \
                                     FILE_TYPE_TLS_SYMLINK        | \
                                     FILE_TYPE_DOT_DESKTOP        | \
                                     FILE_TYPE_DOCUMENTATION)
 
 #define FILE_TYPE_HAVE_ARCH        (FILE_TYPE_OPENGL_LIB         | \
+                                    FILE_TYPE_CUDA_LIB           | \
                                     FILE_TYPE_OPENGL_SYMLINK     | \
+                                    FILE_TYPE_CUDA_SYMLINK       | \
                                     FILE_TYPE_LIBGL_LA           | \
                                     FILE_TYPE_TLS_LIB            | \
                                     FILE_TYPE_TLS_SYMLINK)
@@ -367,16 +379,23 @@ typedef struct {
                                     FILE_TYPE_TLS_SYMLINK)
 
 #define FILE_TYPE_SYMLINK          (FILE_TYPE_OPENGL_SYMLINK     | \
+                                    FILE_TYPE_CUDA_SYMLINK       | \
                                     FILE_TYPE_XLIB_SYMLINK       | \
                                     FILE_TYPE_TLS_SYMLINK        | \
                                     FILE_TYPE_XMODULE_SYMLINK    | \
                                     FILE_TYPE_UTILITY_LIB_SYMLINK| \
                                     FILE_TYPE_UTILITY_BIN_SYMLINK)
 
+#define FILE_TYPE_NEWSYM           (FILE_TYPE_XMODULE_NEWSYM)
+
+#define FILE_TYPE_HAVE_TARGET      (FILE_TYPE_SYMLINK            | \
+                                    FILE_TYPE_NEWSYM)
+
 #define FILE_TYPE_RTLD_CHECKED     (FILE_TYPE_OPENGL_LIB         | \
                                     FILE_TYPE_TLS_LIB)
 
 #define FILE_TYPE_SHARED_LIB       (FILE_TYPE_OPENGL_LIB         | \
+                                    FILE_TYPE_CUDA_LIB           | \
                                     FILE_TYPE_XLIB_SHARED_LIB    | \
                                     FILE_TYPE_TLS_LIB            | \
                                     FILE_TYPE_XMODULE_SHARED_LIB | \
@@ -406,6 +425,7 @@ typedef struct {
  * command line.
  */
 #define DEFAULT_OPENGL_PREFIX           "/usr"
+#define DEFAULT_CUDA_PREFEIX            "/usr"
 #define DEFAULT_X_PREFIX                "/usr/X11R6"
 #define DEFAULT_UTILITY_PREFIX          "/usr"
 #define DEFAULT_DOCUMENTATION_PREFIX    "/usr"
